@@ -59,6 +59,7 @@ class KSCREEN_EXPORT Output : public QObject
         Q_PROPERTY(KScreen::Edid* edid READ edid CONSTANT)
         Q_PROPERTY(QSize sizeMm READ sizeMm CONSTANT)
         Q_PROPERTY(qreal scale READ scale WRITE setScale NOTIFY scaleChanged)
+        Q_PROPERTY(bool followPreferredMode READ followPreferredMode WRITE setFollowPreferredMode NOTIFY followPreferredModeChanged)
 
 
         enum Type {
@@ -97,6 +98,17 @@ class KSCREEN_EXPORT Output : public QObject
         QString name() const;
         void setName(const QString& name);
 
+        /**
+         * Returns an identifying hash for this output.
+         *
+         * The hash is calculated either via the edid hash or if no
+         * edid is available by the output name.
+         *
+         * @return identifying hash of this output
+         * @since 5.15
+         */
+        QString hash() const;
+
         Type type() const;
         void setType(Type type);
 
@@ -166,9 +178,16 @@ class KSCREEN_EXPORT Output : public QObject
         void setPrimary(bool primary);
 
         QList<int> clones() const;
-        void setClones(QList<int> outputlist);
+        void setClones(const QList<int> &outputlist);
 
         void setEdid(const QByteArray &rawData);
+
+        /**
+         * edid returns the output's EDID information if available.
+         *
+         * The output maintains ownership of the returned Edid, so the caller should not delete it.
+         * Note that the edid is only valid as long as the output is alive.
+         */
         Edid* edid() const;
 
         /**
@@ -211,6 +230,21 @@ class KSCREEN_EXPORT Output : public QObject
          */
         void setScale(qreal factor);
 
+        /**
+         * @returns whether the mode should be changed to the new preferred mode
+         * once it changes
+         *
+         * @since 5.15
+         */
+        bool followPreferredMode() const;
+
+        /**
+         * Set whether the preferred mode should be followed through @arg follow
+         *
+         * @since 5.15
+         */
+        void setFollowPreferredMode(bool follow);
+
         void apply(const OutputPtr &other);
     Q_SIGNALS:
         void outputChanged();
@@ -223,6 +257,7 @@ class KSCREEN_EXPORT Output : public QObject
         void isPrimaryChanged();
         void clonesChanged();
         void scaleChanged();
+        void followPreferredModeChanged(bool followPreferredMode);
 
         /** The mode list changed.
          *
